/* $Id: hellosign.java,v 1.20 2014/09/10 11:06:52 tm Exp $
 *
 * PDFlib PLOP DS:
 * generate a document in memory with PDFlib and sign it with PLOP DS
 */

import java.io.*;
import com.pdflib.PLOPException;
import com.pdflib.plop;
import com.pdflib.pdflib;

public class hellosign
{
    public static void main (String argv[])
    {
	pdflib pdf = null;
	plop plop = null;

	try {
	    int font;
	    byte[] contents;
	    String optlist;
	    int doc;

	    /* This is where input files live. Adjust as necessary. */
	    String searchpath = "../data";

	    final String out_filename = "hellosign.pdf";

	    /* Basic signature options */
	    String sign_opts =
		"sigtype=cms " +     /* use sigtype=cades for PAdES signature */
		"ltv=try " +         /* use ltv=full to ensure LTV status */
		/* for use with PKCS11
		"engine=pkcs#11 digitalid={filename=cryptoki.dll} "
		*/
		"engine=builtin digitalid={filename=demorsa2048.p12} password={demo} ";

	    /* ----------- Step 1: generate the document in memory  with PDFlib ---------- */

	    pdf = new pdflib();

	    /* create a new PDF document in memory */
	    pdf.begin_document("", ""); 

	    pdf.set_info("Creator", "hellosign.java");
	    pdf.set_info("Author", "Rainer Ploeckl");
	    pdf.set_info("Title", "Hello world/signed (Java)");

	    font = pdf.load_font("Helvetica-Bold", "winansi", "");

	    pdf.begin_page_ext(595, 842, "");
	    pdf.setfont(font, 24);
	    pdf.set_text_pos(50, 700);
	    pdf.show("Hello world/signed!");
	    pdf.continue_text("(says Java)");
	    pdf.end_page_ext("");

	    pdf.end_document("");
	    contents = pdf.get_buffer();

	    /* --------------- Step 2: sign the document -------------- */

	    plop = new plop();

	    optlist = "searchpath {" + searchpath + "} ";
	    plop.set_option(optlist);

	    /* Create a virtual PVF file from the document data in memory */
            plop.create_pvf("/pvf/hello.pdf", contents, "");

            /* open unsigned input document from PVF file */
            if ((doc = plop.open_document("/pvf/hello.pdf", "")) == -1) {
		throw new Exception("Error: " + plop.get_errmsg());
	    }

	    /* sign the output file */
	    if (plop.prepare_signature(sign_opts) == -1) {
	        throw new Exception("Error: " + plop.get_apiname()
                                        + ": " + plop.get_errmsg());
	    }
	    
	    if (plop.create_document("hellosign.pdf", "input=" + doc) == -1) {
	        throw new Exception("Error: " + plop.get_apiname()
                                        + ": " + plop.get_errmsg());
	    }

            /* close input and output files */
            plop.close_document(doc, "");

	    /* delete PVF file containing input document */
	    if (plop.delete_pvf("/pvf/hello.pdf") == -1) {
		throw new Exception("Error: " + plop.get_errmsg());
	    }


        } catch (PLOPException e) {
            System.err.print("PLOP exception occurred in hellosign sample:\n");
            System.err.print("[" + e.get_errnum() + "] " + e.get_apiname() +
                            ": " + e.get_errmsg() + "\n");
        } catch (Exception e) {
            System.err.println(e.getMessage());
	} finally {
	    /* delete the PLOP object */
	    if (plop != null) plop.delete();

	    /* delete the PDFlib object */
	    if (pdf != null) {
		try { 
		    pdf.delete();
		} catch (Exception e) {
		    System.exit(2);
		}
	    }
	}
    }
}
