#!/usr/bin/env ruby
# $Id: insertxmp.rb,v 1.7 2014/09/10 12:05:04 rp Exp $
#
# PDFlib PLOP: PDF Linearization, Optimization, Protection
# mini sample for inserting XMP metadata in PDF documents
#
#

require './PLOP'

# Directory where files will be searched
searchpath = "../data"
# input document
in_filename  = "PLOP-datasheet.pdf"
# output document
out_filename = "PLOP-datasheet-xmp.pdf"

# Option list for the generated output document.
# Some alternatives for the option list using the supplied XMP samples:
#
# Insert custom metadata for the GWG (Ghent Workgroup)
# Ad Ticket scheme (see http://www.gwg.org/Jobtickets.phtml):
# "metadata={filename=gwg_ad_ticket.xmp validate=xmp2004}"
#
# Insert custom metadata based on Acme's enterprise schema:
# "metadata={filename=acme.xmp}"
#
# Insert a custom "engineering" schema for scanned documents:
# This works best with a PDF/A-1 input document (e.g. mini_pdfa1.pdf),
# and requires XMP input which conforms to PDF/A-1:
# "metadata={filename=engineering.xmp}"
#
# Insert a PDF/A extension schema after validating the XMP for PDF/A-1.
# This works best with a PDF/A-1 input document (e.g. mini_pdfa1.pdf),
# and requires XMP input which conforms to PDF/A-1:
# "metadata={filename=machine_pdfa1.xmp validate=pdfa1}"
#

base_opts = "metadata={filename=gwg_ad_ticket.xmp} "

# create a new PLOP object
plop = PLOP.new

begin
    plop.set_option("searchpath=" + searchpath)

    # open input file
    if ((doc = plop.open_document(in_filename, "")) == -1)
	raise "ERROR: " + plop.get_errmsg()
    end

    # create the output file and add XMP metadata
    optlist = "#{base_opts} input=#{doc}"
    if (plop.create_document(out_filename, optlist) == -1)
	raise "ERROR: " + plop.get_errmsg()
    end

    # close input files
    plop.close_document(doc, "")

rescue PLOPException => pe
    print pe.backtrace.join("\n")
    printf("PLOP exception occurred in insertxmp:\n")
    print "[" + pe.get_errnum.to_s + "] " + pe.get_apiname + \
                        ": " + pe.get_errmsg + "\n"
rescue Exception => e
    print e.backtrace.join("\n") + "\n" + e.to_s + "\n"
ensure
    plop.delete() if plop
end
